@@ -6,9 +6,9 @@ from sphinx.util import logging
 from sphinx import addnodes
 import sass
 
-from .launch import update_thebelab_context, init_thebelab_core, add_hub_urls
+from .launch import add_hub_urls
 
-__version__ = "0.0.26"
+__version__ = "0.0.29"
 SPHINX_LOGGER = logging.getLogger(__name__)
 
 
@@ -168,6 +168,11 @@ def add_to_context(app, pagename, templatename, context, doctree):
 
     context["nav_to_html_list"] = nav_to_html_list
 
+    # Update the page title because HTML makes it into the page title occasionally
+    if pagename in app.env.titles:
+        title = app.env.titles[pagename]
+        context["pagetitle"] = title.astext()
+
     # Add a shortened page text to the context using the sections text
     if doctree:
         description = ""
@@ -223,6 +228,52 @@ def add_to_context(app, pagename, templatename, context, doctree):
             context[key] = _string_or_bool(context[key])
 
 
+def update_thebe_config(app, env, docnames):
+    """Update thebelab configuration with SBT-specific values"""
+    theme_options = env.config.html_theme_options
+    if theme_options.get("launch_buttons", {}).get("thebelab") is True:
+        if not hasattr(env.config, "thebe_config"):
+            SPHINX_LOGGER.warning(
+                (
+                    "Thebelab is activated but not added to extensions list. "
+                    "Add `sphinx_thebelab` to your site's extensions list."
+                )
+            )
+            return
+        # Will be empty if it doesn't exist
+        thebe_config = env.config.thebe_config
+    else:
+        return
+
+    if not theme_options.get("launch_buttons", {}).get("thebelab"):
+        return
+
+    # Update the repository branch and URL
+    # Assume that if there's already a thebe_config, then we don't want to over-ride
+    if "repository_url" not in thebe_config:
+        thebe_config["repository_url"] = theme_options.get("repository_url")
+    if "repository_branch" not in thebe_config:
+        branch = theme_options.get("repository_branch")
+        if not branch:
+            # Explicitly check in case branch is ""
+            branch = "master"
+        thebe_config["repository_branch"] = branch
+
+    # Update the selectors to find thebe-enabled cells
+    selector = thebe_config.get("selector", "") + ",.cell"
+    thebe_config["selector"] = selector.lstrip(",")
+
+    selector_input = (
+        thebe_config.get("selector_input", "") + ",.cell_input div.highlight"
+    )
+    thebe_config["selector_input"] = selector_input.lstrip(",")
+
+    selector_output = thebe_config.get("selector_output", "") + ",.cell_output"
+    thebe_config["selector_output"] = selector_output.lstrip(",")
+
+    env.config.thebe_config = thebe_config
+
+
 def _string_or_bool(var):
     if isinstance(var, str):
         return var.lower() == "true"
@@ -259,6 +310,7 @@ class Margin(directives.body.Sidebar):
 
 def setup(app):
     compile_scss()
+    app.connect("env-before-read-docs", update_thebe_config)
 
     # Configuration for Juypter Book
     app.connect("html-page-context", add_hub_urls)
@@ -267,9 +319,6 @@ def setup(app):
 
     app.add_html_theme("sphinx_book_theme", get_html_theme_path())
     app.connect("html-page-context", add_to_context)
+
     app.add_js_file("sphinx-book-theme.js")
     app.add_directive("margin", Margin)
-
-    # Include Thebelab for interactive code if it's enabled
-    app.connect("env-before-read-docs", init_thebelab_core)
-    app.connect("doctree-resolved", update_thebelab_context)
